=======
Views
=======

Morp inherits its view implementation from `morepath views
<https://morepath.readthedocs.io/en/latest/views.html>`_

Every ``morpfw.Model`` and ``morpfw.Collection`` are models which are published
on the defined path, and you can attach views to it.

